/**
 *  @file deepSleep.cpp
 *  @brief Support for nrf52 deep sleep / low power modes
 *
 *  Arduino code for Flying Silicon Airspeed/Vario Probe and TotalVario Android app.
 *
 *  For more information refer to:
 *  https://flyingsilicon.blogspot.com/ <br>
 *  https://totalvario.blogspot.com/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 *  See the GNU General Public License <http://www.gnu.org/licenses/>
 *  for more details.
 */
#ifdef ARDUINO_ARCH_NRF52

#include <Arduino.h>
#include "deepSleep.h"

// TODO check how to put sensors in low power mode

/**
 * Enter low power mode
 * @return 1 if success, else 0
 */
int setLowPowerMode(void) {
   return (sd_power_mode_set(NRF_POWER_MODE_LOWPWR) == NRF_SUCCESS ) ? 1 : 0;
}

/**
 * Enter deep sleep mode
 * DOES NOT RETURN IF DEEP SLEEP WAS ACTIVATED
 */
void enterDeepSleep(void) {

	// sd_power_system_off() works only when no 'EasyDMA' transfer is active
	// this is achieved by disabling all peripherals that might use it
	NRF_UARTE0->ENABLE = UARTE_ENABLE_ENABLE_Disabled;	// disable UART
	NRF_SAADC ->ENABLE = (SAADC_ENABLE_ENABLE_Disabled << SAADC_ENABLE_ENABLE_Pos); // disable ADC
	NRF_PWM0  ->ENABLE = (PWM_ENABLE_ENABLE_Disabled << PWM_ENABLE_ENABLE_Pos); // disable all pwm instances
	NRF_PWM1  ->ENABLE = (PWM_ENABLE_ENABLE_Disabled << PWM_ENABLE_ENABLE_Pos);
	NRF_PWM2  ->ENABLE = (PWM_ENABLE_ENABLE_Disabled << PWM_ENABLE_ENABLE_Pos);
	NRF_TWIM1 ->ENABLE = (TWIM_ENABLE_ENABLE_Disabled << TWIM_ENABLE_ENABLE_Pos);	// disable TWI Master
	NRF_TWIS1 ->ENABLE = (TWIS_ENABLE_ENABLE_Disabled << TWIS_ENABLE_ENABLE_Pos);	// disable TWI Slave
	
	sd_power_system_off();
   // should not be reached in deep sleep
}

#endif // ARDUINO_ARCH_NRF52
