/**
 *  @file fsUart.h
 *  @brief Helper to enable usage of BLE Uart with different UUID sets.
 *
 *  Arduino code for Flying Silicon Airspeed/Vario Probe and TotalVario Android app.
 *
 *  For more information refer to:
 *  https://flyingsilicon.blogspot.com/ <br>
 *  https://totalvario.blogspot.com/
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 *  See the GNU General Public License <http://www.gnu.org/licenses/>
 *  for more details.
 */
#ifndef _FSUART_H_
#define _FSUART_H_

// Need to know the BLEUart class
#include <bluefruit.h>

//! Adafruit UART Tx and Rx FIFO size in bytes
#define FIFO_SZ 128
//! Use the HM-10 UUID set
#define USE_HM10_UUID

/*
 * NORDIC UUIDs are defined in BLEUart.h / BLEUart.cpp
 *
 * Service: 6E400001-B5A3-F393-E0A9-E50E24DCCA9E
 * RXD    : 6E400002-B5A3-F393-E0A9-E50E24DCCA9E
 * TXD    : 6E400003-B5A3-F393-E0A9-E50E24DCCA9E
 *
 * const uint8_t BLEUART_UUID_SERVICE[] = {
 *     0x9E, 0xCA, 0xDC, 0x24, 0x0E, 0xE5, 0xA9, 0xE0,
 *     0x93, 0xF3, 0xA3, 0xB5, 0x01, 0x00, 0x40, 0x6E
 * };
 * const uint8_t BLEUART_UUID_CHR_RXD[] = {
 *     0x9E, 0xCA, 0xDC, 0x24, 0x0E, 0xE5, 0xA9, 0xE0,
 *     0x93, 0xF3, 0xA3, 0xB5, 0x02, 0x00, 0x40, 0x6E
 * };
 * const uint8_t BLEUART_UUID_CHR_TXD[] = {
 *     0x9E, 0xCA, 0xDC, 0x24, 0x0E, 0xE5, 0xA9, 0xE0,
 *     0x93, 0xF3, 0xA3, 0xB5, 0x03, 0x00, 0x40, 0x6E
 * };
 */

/*
 * HM10 UUIDs
 *
 * Service: 0000FFE0-0000-1000-8000-00805F9B34FB
 * RXD    : 0000FFE2-0000-1000-8000-00805F9B34FB
 * TXD    : 0000FFE1-0000-1000-8000-00805F9B34FB
 */
#ifdef USE_HM10_UUID
static const uint8_t HM10_UUID_SERVICE[] = {
    0xFB, 0x34, 0x9B, 0x5F, 0x80, 0x00, 0x00, 0x80,
    0x00, 0x10, 0x00, 0x00, 0xE0, 0xFF, 0x00, 0x00
};
static const uint8_t HM10_UUID_CHR_RXD[] = {
    0xFB, 0x34, 0x9B, 0x5F, 0x80, 0x00, 0x00, 0x80,
    0x00, 0x10, 0x00, 0x00, 0xE2, 0xFF, 0x00, 0x00
};
static const uint8_t HM10_UUID_CHR_TXD[] = {
    0xFB, 0x34, 0x9B, 0x5F, 0x80, 0x00, 0x00, 0x80,
    0x00, 0x10, 0x00, 0x00, 0xE1, 0xFF, 0x00, 0x00
};
#endif

/**
 * Extends the original BLEUart class so that the characteristics UUIDs can be chosen.
 */
class FsUart : public BLEUart {

public:
   /**
    * Default cnstructor, nothing else needed
    */
   FsUart() : BLEUart(FIFO_SZ) {
#ifdef USE_HM10_UUID
      setUuid(HM10_UUID_SERVICE);
      _rxd = BLECharacteristic(HM10_UUID_CHR_RXD);
      _txd = BLECharacteristic(HM10_UUID_CHR_TXD);
#else
      setUuid(BLEUART_UUID_SERVICE);
      _rxd = BLECharacteristic(BLEUART_UUID_CHR_RXD);
      _txd = BLECharacteristic(BLEUART_UUID_CHR_TXD);
#endif
   };
};

#endif // _FSUART_H_
