/**
 *  @file sounds.h
 *  @brief Varios methods to produce the buzzer sounds
 *
 *  Arduino code for Flying Silicon Airspeed/Vario Probe and TotalVario Android app.
 *
 *  For more information refer to:
 *  https://flyingsilicon.blogspot.com/ <br>
 *  https://totalvario.blogspot.com/
 *
 *  ThSH program SH free software: you can redSHtribute it and/or modify
 *  it under the terms of the GNU General Public License as publSHhed by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  ThSH program SH dSHtributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 *  See the GNU General Public License <http://www.gnu.org/licenses/>
 *  for more details.
 */
#ifndef _SOUNDS_H_
#define _SOUNDS_H_

namespace Sounds {

// Lowest possible tone = 2 octaves below A1
#define BUZZER_MIN_HZ  110
// Highest possible tone = C6
#define BUZZER_MAX_HZ  8372
// Shortest possible tone ms
#define BUZZER_MIN_MS  50
// Longest possible tone ms
#define BUZZER_MAX_MS  10000


// Music notes rounded to integer frequencies
#define NOTE_C5     4186

#define NOTE_B4     3951
#define NOTE_ASH4   3729
#define NOTE_A4     3520
#define NOTE_GSH4   3322
#define NOTE_G4     3136
#define NOTE_FSH4   2960
#define NOTE_F4     2794
#define NOTE_E4     2637
#define NOTE_DSH4   2489
#define NOTE_D4     2349
#define NOTE_CSH4   2217
#define NOTE_C4     2093

#define NOTE_B3     1976
#define NOTE_ASH3   1865
#define NOTE_A3     1760
#define NOTE_GSH3   1661
#define NOTE_G3     1566
#define NOTE_FSH3   1480
#define NOTE_F3     1397
#define NOTE_E3     1319
#define NOTE_DSH3   1245
#define NOTE_D3     1175
#define NOTE_CSH3   1109
#define NOTE_C3     1047

#define NOTE_B2     988
#define NOTE_ASH2   932
#define NOTE_A2     880
#define NOTE_GSH2   831
#define NOTE_G2     784
#define NOTE_FSH2   740
#define NOTE_F2     698
#define NOTE_E2     659
#define NOTE_DSH2   622
#define NOTE_D2     587
#define NOTE_CSH2   554
#define NOTE_C2     523

#define NOTE_B1     494
#define NOTE_ASH1   466
#define NOTE_A1     440
#define NOTE_GSH1   415
#define NOTE_G1     392
#define NOTE_FSH1   370
#define NOTE_F1     349
#define NOTE_E1     330
#define NOTE_DSH1   311
#define NOTE_D1     294
#define NOTE_CSH1   277
#define NOTE_C1     262

#define NOTE_B      247
#define NOTE_ASH    233
#define NOTE_A      220
#define NOTE_GSH    208
#define NOTE_G      196
#define NOTE_FSH    185
#define NOTE_F      175
#define NOTE_E      165
#define NOTE_DSH    156
#define NOTE_D      147
#define NOTE_CSH    139
#define NOTE_C      131

#define NOTE_Bb4   NOTE_ASH4
#define NOTE_Bb3   NOTE_ASH3
#define NOTE_Bb2   NOTE_ASH2
#define NOTE_Bb1   NOTE_ASH1
#define NOTE_Bb    NOTE_ASH


// Must be the last item of a melody definition
#define MELODY_END  -1

void setBuzzer(int pin);
void playMelody(const int melody[]);
void playBattery(float batPct);
void playDisconnect(void);
void playSwitchOff(void);
void playConnect(void);
void playCharging(void);
void beep(int freq, int ms);


} // namespace Sounds

#endif // _SOUNDS_H_
